# canva-alpha-ti
API for building integrations with Canva via a REST api

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: latest
- Package version: 0.0.1
- Generator version: 7.11.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://community.canva.dev/](https://community.canva.dev/)

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import canva_alpha_ti
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import canva_alpha_ti
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import canva_alpha_ti
from canva_alpha_ti.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.canva.com/rest
# See configuration.py for a list of all supported configuration parameters.
configuration = canva_alpha_ti.Configuration(
    host = "https://api.canva.com/rest"
)



# Enter a context with an instance of the API client
with canva_alpha_ti.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = canva_alpha_ti.AppApi(api_client)
    app_id = 'app_id_example' # str | The app id

    try:
        api_response = api_instance.get_app_jwks(app_id)
        print("The response of AppApi->get_app_jwks:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AppApi->get_app_jwks: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.canva.com/rest*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AppApi* | [**get_app_jwks**](docs/AppApi.md#get_app_jwks) | **GET** /v1/apps/{appId}/jwks | 
*AssetApi* | [**create_asset_upload_job**](docs/AssetApi.md#create_asset_upload_job) | **POST** /v1/asset-uploads | 
*AssetApi* | [**delete_asset**](docs/AssetApi.md#delete_asset) | **DELETE** /v1/assets/{assetId} | 
*AssetApi* | [**get_asset**](docs/AssetApi.md#get_asset) | **GET** /v1/assets/{assetId} | 
*AssetApi* | [**get_asset_upload_job**](docs/AssetApi.md#get_asset_upload_job) | **GET** /v1/asset-uploads/{jobId} | 
*AssetApi* | [**update_asset**](docs/AssetApi.md#update_asset) | **PATCH** /v1/assets/{assetId} | 
*AutofillApi* | [**create_design_autofill_job**](docs/AutofillApi.md#create_design_autofill_job) | **POST** /v1/autofills | 
*AutofillApi* | [**get_design_autofill_job**](docs/AutofillApi.md#get_design_autofill_job) | **GET** /v1/autofills/{jobId} | 
*BrandTemplateApi* | [**get_brand_template**](docs/BrandTemplateApi.md#get_brand_template) | **GET** /v1/brand-templates/{brandTemplateId} | 
*BrandTemplateApi* | [**get_brand_template_dataset**](docs/BrandTemplateApi.md#get_brand_template_dataset) | **GET** /v1/brand-templates/{brandTemplateId}/dataset | 
*BrandTemplateApi* | [**list_brand_templates**](docs/BrandTemplateApi.md#list_brand_templates) | **GET** /v1/brand-templates | 
*CommentApi* | [**create_comment**](docs/CommentApi.md#create_comment) | **POST** /v1/comments | 
*CommentApi* | [**create_reply**](docs/CommentApi.md#create_reply) | **POST** /v1/comments/{commentId}/replies | 
*CommentApi* | [**get_comment**](docs/CommentApi.md#get_comment) | **GET** /v1/designs/{designId}/comments/{commentId} | 
*ConnectApi* | [**get_signing_public_keys**](docs/ConnectApi.md#get_signing_public_keys) | **GET** /v1/connect/keys | 
*DesignApi* | [**create_design**](docs/DesignApi.md#create_design) | **POST** /v1/designs | 
*DesignApi* | [**get_design**](docs/DesignApi.md#get_design) | **GET** /v1/designs/{designId} | 
*DesignApi* | [**get_design_export_formats**](docs/DesignApi.md#get_design_export_formats) | **GET** /v1/designs/{designId}/export-formats | 
*DesignApi* | [**get_design_pages**](docs/DesignApi.md#get_design_pages) | **GET** /v1/designs/{designId}/pages | 
*DesignApi* | [**list_designs**](docs/DesignApi.md#list_designs) | **GET** /v1/designs | 
*DesignImportApi* | [**create_design_import_job**](docs/DesignImportApi.md#create_design_import_job) | **POST** /v1/imports | 
*DesignImportApi* | [**get_design_import_job**](docs/DesignImportApi.md#get_design_import_job) | **GET** /v1/imports/{jobId} | 
*ExportApi* | [**create_design_export_job**](docs/ExportApi.md#create_design_export_job) | **POST** /v1/exports | 
*ExportApi* | [**get_design_export_job**](docs/ExportApi.md#get_design_export_job) | **GET** /v1/exports/{exportId} | 
*FolderApi* | [**create_folder**](docs/FolderApi.md#create_folder) | **POST** /v1/folders | 
*FolderApi* | [**delete_folder**](docs/FolderApi.md#delete_folder) | **DELETE** /v1/folders/{folderId} | 
*FolderApi* | [**get_folder**](docs/FolderApi.md#get_folder) | **GET** /v1/folders/{folderId} | 
*FolderApi* | [**list_folder_items**](docs/FolderApi.md#list_folder_items) | **GET** /v1/folders/{folderId}/items | 
*FolderApi* | [**move_folder_item**](docs/FolderApi.md#move_folder_item) | **POST** /v1/folders/move | 
*FolderApi* | [**update_folder**](docs/FolderApi.md#update_folder) | **PATCH** /v1/folders/{folderId} | 
*OauthApi* | [**exchange_access_token**](docs/OauthApi.md#exchange_access_token) | **POST** /v1/oauth/token | 
*OauthApi* | [**introspect_token**](docs/OauthApi.md#introspect_token) | **POST** /v1/oauth/introspect | 
*OauthApi* | [**revoke_tokens**](docs/OauthApi.md#revoke_tokens) | **POST** /v1/oauth/revoke | 
*UserApi* | [**get_user_profile**](docs/UserApi.md#get_user_profile) | **GET** /v1/users/me/profile | 
*UserApi* | [**users_me**](docs/UserApi.md#users_me) | **GET** /v1/users/me | 


## Documentation For Models

 - [AcceptedSuggestionEventType](docs/AcceptedSuggestionEventType.md)
 - [AddSuggestionContent](docs/AddSuggestionContent.md)
 - [ApprovalRequestAction](docs/ApprovalRequestAction.md)
 - [ApprovalResponseAction](docs/ApprovalResponseAction.md)
 - [Asset](docs/Asset.md)
 - [AssetSummary](docs/AssetSummary.md)
 - [AssetType](docs/AssetType.md)
 - [AssetUploadError](docs/AssetUploadError.md)
 - [AssetUploadErrorCode](docs/AssetUploadErrorCode.md)
 - [AssetUploadJob](docs/AssetUploadJob.md)
 - [AssetUploadMetadata](docs/AssetUploadMetadata.md)
 - [AssetUploadStatus](docs/AssetUploadStatus.md)
 - [AutofillError](docs/AutofillError.md)
 - [AutofillErrorCode](docs/AutofillErrorCode.md)
 - [BooleanDataTableCell](docs/BooleanDataTableCell.md)
 - [BrandTemplate](docs/BrandTemplate.md)
 - [ChartDataField](docs/ChartDataField.md)
 - [Comment](docs/Comment.md)
 - [CommentEvent](docs/CommentEvent.md)
 - [CommentEventType](docs/CommentEventType.md)
 - [CommentNotificationContent](docs/CommentNotificationContent.md)
 - [CommentObject](docs/CommentObject.md)
 - [CommentObjectInput](docs/CommentObjectInput.md)
 - [CommentThreadType](docs/CommentThreadType.md)
 - [CreateAssetUploadJobResponse](docs/CreateAssetUploadJobResponse.md)
 - [CreateCommentRequest](docs/CreateCommentRequest.md)
 - [CreateCommentResponse](docs/CreateCommentResponse.md)
 - [CreateDesignAutofillJobRequest](docs/CreateDesignAutofillJobRequest.md)
 - [CreateDesignAutofillJobResponse](docs/CreateDesignAutofillJobResponse.md)
 - [CreateDesignAutofillJobResult](docs/CreateDesignAutofillJobResult.md)
 - [CreateDesignExportJobRequest](docs/CreateDesignExportJobRequest.md)
 - [CreateDesignExportJobResponse](docs/CreateDesignExportJobResponse.md)
 - [CreateDesignImportJobResponse](docs/CreateDesignImportJobResponse.md)
 - [CreateDesignRequest](docs/CreateDesignRequest.md)
 - [CreateDesignResponse](docs/CreateDesignResponse.md)
 - [CreateFolderRequest](docs/CreateFolderRequest.md)
 - [CreateFolderResponse](docs/CreateFolderResponse.md)
 - [CreateReplyRequest](docs/CreateReplyRequest.md)
 - [CreateReplyResponse](docs/CreateReplyResponse.md)
 - [CustomDesignTypeInput](docs/CustomDesignTypeInput.md)
 - [DataField](docs/DataField.md)
 - [DataTable](docs/DataTable.md)
 - [DataTableCell](docs/DataTableCell.md)
 - [DataTableRow](docs/DataTableRow.md)
 - [DatasetChartValue](docs/DatasetChartValue.md)
 - [DatasetFilter](docs/DatasetFilter.md)
 - [DatasetImageValue](docs/DatasetImageValue.md)
 - [DatasetTextValue](docs/DatasetTextValue.md)
 - [DatasetValue](docs/DatasetValue.md)
 - [DateDataTableCell](docs/DateDataTableCell.md)
 - [DeleteSuggestionContent](docs/DeleteSuggestionContent.md)
 - [Design](docs/Design.md)
 - [DesignAccessRequestedNotificationContent](docs/DesignAccessRequestedNotificationContent.md)
 - [DesignApprovalRequestedNotificationContent](docs/DesignApprovalRequestedNotificationContent.md)
 - [DesignApprovalResponseNotificationContent](docs/DesignApprovalResponseNotificationContent.md)
 - [DesignApprovalReviewerInvalidatedNotificationContent](docs/DesignApprovalReviewerInvalidatedNotificationContent.md)
 - [DesignAutofillJob](docs/DesignAutofillJob.md)
 - [DesignAutofillJobResult](docs/DesignAutofillJobResult.md)
 - [DesignAutofillStatus](docs/DesignAutofillStatus.md)
 - [DesignCommentObject](docs/DesignCommentObject.md)
 - [DesignCommentObjectInput](docs/DesignCommentObjectInput.md)
 - [DesignExportStatus](docs/DesignExportStatus.md)
 - [DesignImportError](docs/DesignImportError.md)
 - [DesignImportErrorCode](docs/DesignImportErrorCode.md)
 - [DesignImportJob](docs/DesignImportJob.md)
 - [DesignImportJobResult](docs/DesignImportJobResult.md)
 - [DesignImportMetadata](docs/DesignImportMetadata.md)
 - [DesignImportStatus](docs/DesignImportStatus.md)
 - [DesignItem](docs/DesignItem.md)
 - [DesignLinks](docs/DesignLinks.md)
 - [DesignMentionNotificationContent](docs/DesignMentionNotificationContent.md)
 - [DesignPage](docs/DesignPage.md)
 - [DesignSummary](docs/DesignSummary.md)
 - [DesignTypeInput](docs/DesignTypeInput.md)
 - [EdDsaJwk](docs/EdDsaJwk.md)
 - [Error](docs/Error.md)
 - [ErrorCode](docs/ErrorCode.md)
 - [ExchangeAccessTokenResponse](docs/ExchangeAccessTokenResponse.md)
 - [ExportError](docs/ExportError.md)
 - [ExportErrorCode](docs/ExportErrorCode.md)
 - [ExportFormat](docs/ExportFormat.md)
 - [ExportFormatOptions](docs/ExportFormatOptions.md)
 - [ExportJob](docs/ExportJob.md)
 - [ExportPageSize](docs/ExportPageSize.md)
 - [ExportQuality](docs/ExportQuality.md)
 - [Folder](docs/Folder.md)
 - [FolderAccessRequestedNotificationContent](docs/FolderAccessRequestedNotificationContent.md)
 - [FolderItem](docs/FolderItem.md)
 - [FolderItemSortBy](docs/FolderItemSortBy.md)
 - [FolderItemSummary](docs/FolderItemSummary.md)
 - [FolderItemType](docs/FolderItemType.md)
 - [FolderSummary](docs/FolderSummary.md)
 - [FormatSuggestionContent](docs/FormatSuggestionContent.md)
 - [GetAppJwksResponse](docs/GetAppJwksResponse.md)
 - [GetAssetResponse](docs/GetAssetResponse.md)
 - [GetAssetUploadJobResponse](docs/GetAssetUploadJobResponse.md)
 - [GetBrandTemplateDatasetResponse](docs/GetBrandTemplateDatasetResponse.md)
 - [GetBrandTemplateResponse](docs/GetBrandTemplateResponse.md)
 - [GetCommentResponse](docs/GetCommentResponse.md)
 - [GetDesignAutofillJobResponse](docs/GetDesignAutofillJobResponse.md)
 - [GetDesignExportFormatsResponse](docs/GetDesignExportFormatsResponse.md)
 - [GetDesignExportJobResponse](docs/GetDesignExportJobResponse.md)
 - [GetDesignImportJobResponse](docs/GetDesignImportJobResponse.md)
 - [GetDesignPagesResponse](docs/GetDesignPagesResponse.md)
 - [GetDesignResponse](docs/GetDesignResponse.md)
 - [GetFolderResponse](docs/GetFolderResponse.md)
 - [GetListDesignResponse](docs/GetListDesignResponse.md)
 - [GetSigningPublicKeysResponse](docs/GetSigningPublicKeysResponse.md)
 - [GifExportFormat](docs/GifExportFormat.md)
 - [Group](docs/Group.md)
 - [ImageDataField](docs/ImageDataField.md)
 - [ImageItem](docs/ImageItem.md)
 - [ImportError](docs/ImportError.md)
 - [ImportErrorCode](docs/ImportErrorCode.md)
 - [ImportStatus](docs/ImportStatus.md)
 - [ImportStatusState](docs/ImportStatusState.md)
 - [IntrospectTokenResponse](docs/IntrospectTokenResponse.md)
 - [JpgExportFormat](docs/JpgExportFormat.md)
 - [JsonWebKey](docs/JsonWebKey.md)
 - [ListBrandTemplatesResponse](docs/ListBrandTemplatesResponse.md)
 - [ListFolderItemsResponse](docs/ListFolderItemsResponse.md)
 - [MentionSuggestionEventType](docs/MentionSuggestionEventType.md)
 - [MoveFolderItemRequest](docs/MoveFolderItemRequest.md)
 - [Mp4ExportFormat](docs/Mp4ExportFormat.md)
 - [Mp4ExportQuality](docs/Mp4ExportQuality.md)
 - [NewSuggestionEventType](docs/NewSuggestionEventType.md)
 - [Notification](docs/Notification.md)
 - [NotificationContent](docs/NotificationContent.md)
 - [NumberDataTableCell](docs/NumberDataTableCell.md)
 - [OauthError](docs/OauthError.md)
 - [OwnershipType](docs/OwnershipType.md)
 - [ParentComment](docs/ParentComment.md)
 - [PdfExportFormat](docs/PdfExportFormat.md)
 - [PngExportFormat](docs/PngExportFormat.md)
 - [PptxExportFormat](docs/PptxExportFormat.md)
 - [PresetDesignTypeInput](docs/PresetDesignTypeInput.md)
 - [PresetDesignTypeName](docs/PresetDesignTypeName.md)
 - [RejectedSuggestionEventType](docs/RejectedSuggestionEventType.md)
 - [ReplaceSuggestionContent](docs/ReplaceSuggestionContent.md)
 - [Reply](docs/Reply.md)
 - [ReplyComment](docs/ReplyComment.md)
 - [ReplySuggestionEventType](docs/ReplySuggestionEventType.md)
 - [ShareAction](docs/ShareAction.md)
 - [ShareDesignNotificationContent](docs/ShareDesignNotificationContent.md)
 - [ShareFolderNotificationContent](docs/ShareFolderNotificationContent.md)
 - [SortByType](docs/SortByType.md)
 - [StringDataTableCell](docs/StringDataTableCell.md)
 - [SuggestionContent](docs/SuggestionContent.md)
 - [SuggestionEventType](docs/SuggestionEventType.md)
 - [SuggestionFormat](docs/SuggestionFormat.md)
 - [SuggestionNotificationContent](docs/SuggestionNotificationContent.md)
 - [SuggestionStatus](docs/SuggestionStatus.md)
 - [SuggestionThreadType](docs/SuggestionThreadType.md)
 - [Team](docs/Team.md)
 - [TeamInviteNotificationContent](docs/TeamInviteNotificationContent.md)
 - [TeamUser](docs/TeamUser.md)
 - [TeamUserSummary](docs/TeamUserSummary.md)
 - [TextDataField](docs/TextDataField.md)
 - [Thread](docs/Thread.md)
 - [ThreadType](docs/ThreadType.md)
 - [Thumbnail](docs/Thumbnail.md)
 - [UpdateAssetRequest](docs/UpdateAssetRequest.md)
 - [UpdateAssetResponse](docs/UpdateAssetResponse.md)
 - [UpdateFolderRequest](docs/UpdateFolderRequest.md)
 - [UpdateFolderResponse](docs/UpdateFolderResponse.md)
 - [User](docs/User.md)
 - [UserProfile](docs/UserProfile.md)
 - [UserProfileResponse](docs/UserProfileResponse.md)
 - [UsersMeResponse](docs/UsersMeResponse.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="basicAuth"></a>
### basicAuth

- **Type**: HTTP basic authentication

<a id="oauthAuthCode"></a>
### oauthAuthCode

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://www.canva.com/api/oauth/authorize
- **Scopes**: 
 - **app:read**: View [Canva app](https://www.canva.dev/docs/connect/canva-concepts/#canva-apps) metadata.
 - **app:write**: Create, update, or remove [Canva apps](https://www.canva.dev/docs/connect/canva-concepts/#canva-apps) on the user's behalf.
 - **design:content:read**: View the contents of the user's designs.
 - **design:meta:read**: View the metadata of the user's designs.
 - **design:content:write**: Create designs on the user's behalf.
 - **design:permission:read**: View the permissions assigned to a user's designs.
 - **design:permission:write**: Set, update, or remove the permissions assigned to the user's designs.
 - **folder:read**: View the metadata and contents of the user's folders, including their **Projects** folder.
 - **folder:write**: Add, move, or remove the user's folders. It also lets you edit folder metadata, such as the folder's name.
 - **folder:permission:read**: View permissions assigned to a user's folders.
 - **folder:permission:write**: Set, update, or remove permissions assigned to the user's folders.
 - **asset:read**: View the metadata for the user's assets, such as uploaded images.
 - **asset:write**: Upload, update, or delete assets on the user's behalf.
 - **comment:read**: View the comments on the user's designs, and the associated metadata.
 - **comment:write**: Create comments and replies on the user's designs.
 - **collaboration:event**: Receive webhook notifications about events relevant to the user.
 - **brandtemplate:meta:read**: View the metadata of the brand templates associated with the user's brand.
 - **brandtemplate:content:read**: Read the content of the brand templates associated with the user's brand.
 - **profile:read**: Read a user's profile and account information.


## Author




